==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/es-CO/admin/hardware/form.php <==
<?php

return array(
	'bulk_delete'		=> 'Confirma la Eliminación Masiva de Equipos',
  'bulk_delete_help'	=> 'Revisar los equipos para eliminación masiva. Una vez eliminados, esos equipos pueden ser restaurados, pero no volverán a estar asociados a ninguno de los usuarios a los que estén asignados actualmente.',
  'bulk_delete_warn'	=> 'Estás a punto de eliminar :asset_count equipos.',
	'bulk_update'		=> 'Actualización masiva de Equipos',
	'bulk_update_help'	=> 'Este formulario te permite actualizar múltiples equipos simultáneamente. Solo debes completar los campos que quieres modificar. Todo campo en blanco permanecerá sin cambios. ',
	'bulk_update_warn'	=> 'Estás a punto de editar las propiedades de :asset_count equipos.',
    'checkedout_to'		=> 'Asignado a',
    'checkout_date'		=> 'Fecha de asignación',
    'checkin_date'		=> 'Fecha de devolución',
    'checkout_to'		=> 'Asignar a',
    'cost'				=> 'Precio de compra',
    'create'			=> 'Creación de Equipo',
    'date'				=> 'Fecha de Compra',
    'depreciation'	    => 'Depreciación',
    'depreciates_on'	=> 'Se deprecia en',
    'default_location'	=> 'Ubicación Predeterminada',
    'eol_date'			=> 'Fecha Fin Vida Útil',
    'eol_rate'			=> 'Vita Útil',
    'expected_checkin'  => 'Fecha Esperada de Devolución',
    'expires'			=> 'Expira',
    'fully_depreciated'	=> 'Totalmente Depreciado',
    'help_checkout'		=> 'Si deseas asignar este equipo inmediatamente, selecciona "Listo para Asignar" de la lista de estados de arriba. ',
    'mac_address'		=> 'Dirección MAC',
    'manufacturer'		=> 'Fabricante',
    'model'				=> 'Modelo',
    'months'			=> 'meses',
    'name'				=> 'Nombre del Equipo',
    'notes'				=> 'Notas',
    'order'				=> 'Orden Número',
    'qr'				=> 'Código QR',
    'requestable'		=> 'Los usuarios pueden solicitar este equipo',
    'select_statustype'	=> 'Selecciona Tipo de Estado',
    'serial'			=> 'Número de serie',
    'status'			=> 'Estado',
    'tag'				=> 'Etiqueta del Equipo',
    'update'			=> 'Actualizar Equipo',
    'warranty'			=> 'Garantía',
		'warranty_expires'		=> 'Vencimiento de Garantía',
    'years'				=> 'años',
)
;

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/es-CO/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Confirma la Eliminación Masiva de Equipos',
  'bulk_delete_help'	=> 'Revisar los equipos para eliminación masiva. Una vez eliminados, esos equipos pueden ser restaurados, pero no volverán a estar asociados a ninguno de los usuarios a los que estén asignados actualmente.',
  'bulk_delete_warn'	=> 'Estás a punto de eliminar :asset_count equipos.',
    'bulk_update'		=> 'Actualización masiva de Equipos',
    'bulk_update_help'	=> 'Este formulario te permite actualizar múltiples equipos simultáneamente. Solo debes completar los campos que quieres modificar. Todo campo en blanco permanecerá sin cambios. ',
    'bulk_update_warn'	=> 'Estás a punto de editar las propiedades de :asset_count equipos.',
    'checkedout_to'		=> 'Asignado a',
    'checkout_date'		=> 'Fecha de asignación',
    'checkin_date'		=> 'Fecha de devolución',
    'checkout_to'		=> 'Asignar a',
    'cost'				=> 'Precio de compra',
    'create'			=> 'Creación de Equipo',
    'date'				=> 'Fecha de Compra',
    'depreciation'	    => 'Depreciación',
    'depreciates_on'	=> 'Se deprecia en',
    'default_location'	=> 'Ubicación Predeterminada',
    'eol_date'			=> 'Fecha Fin Vida Útil',
    'eol_rate'			=> 'Vita Útil',
    'expected_checkin'  => 'Fecha Esperada de Devolución',
    'expires'			=> 'Expira',
    'fully_depreciated'	=> 'Totalmente Depreciado',
    'help_checkout'		=> 'Si deseas asignar este equipo inmediatamente, selecciona "Listo para Asignar" de la lista de estados de arriba. ',
    'mac_address'		=> 'Dirección MAC',
    'manufacturer'		=> 'Fabricante',
    'model'				=> 'Modelo',
    'months'			=> 'meses',
    'name'				=> 'Nombre del Equipo',
    'notes'				=> 'Notas',
    'order'				=> 'Orden Número',
    'qr'				=> 'Código QR',
    'requestable'		=> 'Los usuarios pueden solicitar este equipo',
    'select_statustype'	=> 'Selecciona Tipo de Estado',
    'serial'			=> 'Número de serie',
    'status'			=> 'Estado',
    'tag'				=> 'Etiqueta del Equipo',
    'update'			=> 'Actualizar Equipo',
    'warranty'			=> 'Garantía',
        'warranty_expires'		=> 'Vencimiento de Garantía',
    'years'				=> 'años',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing...',
];
